$( document ).ready(function() {
  $( ".install" ).click(function() {
    $( ".loader" ).css('display', 'block');
  });

  $( ".upgrade" ).click(function() {
    $( ".loader" ).css('display', 'block');
  });

  $( ".remove" ).click(function() {
    $( ".loader" ).css('display', 'block');
  });
});