@media only screen and (max-device-width : 1024px) {
  main {
      width: 100%;
  }
}
body {
  padding-left: 5px !important;
  font-family: roboto !important;
  display: flex;
  min-height: 100vh;
  flex-direction: column;
}
main {
flex: 1 0 auto;
width: 60%;
margin: auto;
}
.fa {
  font-size:18px !important;
}
code {
  font-family: roboto !important;
  font-size: 14px !important;
}
nav {
  background-color: #546e7a !important;
  margin-bottom: 32px;
}
.card-title {
  color: white;
}
footer {
  margin-right: 5px;
}
header {
  margin-right: 5px;
}

.log {
  width: 90% !important;
}

.suites {
  width: 60% !important;
}

.suite {
  width: 90% !important;
}

.suiterow {
  position: absolute;
  width: 90% !important;
}


.loader {
  border: 16px solid #f3f3f3;
  border-radius: 50%;
  border-top: 16px solid #546e7a;
  width: 120px;
  right: -40%;
  margin-top: 10%;
  display: none;
  position: relative;
  height: 120px;
  -webkit-animation: spin 2s linear infinite; /* Safari */
  animation: spin 2s linear infinite;
}

/* Safari */
@-webkit-keyframes spin {
  0% { -webkit-transform: rotate(0deg); }
  100% { -webkit-transform: rotate(360deg); }
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}
